/*     */ package it.imwatch;
/*     */ 
/*     */ import android.content.Context;
/*     */ import android.os.Handler;
/*     */ import android.util.Log;
/*     */ import laser.testcompass.KyneticsSensors;
/*     */ 
/*     */ public class SimpleShakeDetector
/*     */ {
/*     */   private static final String TAG = "SimpleShakeDetector";
/*     */   public static final float DEFAULT_THRESHOLD = 10.0F;
/*     */   public static final int DEFAULT_UPDATE_INTERVAL = 10;
/*     */   public static final int DEFAULT_NO_MOVEMENT = 5;
/*     */   public static final int DEFAULT_MIN_GESTURE_SIZE = 14;
/*  47 */   private float mThreshold = 10.0F;
/*  48 */   private int mNoMovement = 5;
/*  49 */   private int mUpdateInterval = 10;
/*  50 */   private int mMinGestureSize = 14;
/*     */   KyneticsSensors mSensors;
/*  56 */   int steps = 0; int stepsNoMov = 0;
/*     */ 
/*  58 */   Handler handler = new Handler();
/*     */   Runnable update;
/*     */   Context context;
/*  61 */   boolean stopped = false;
/*     */   OnShakeListener mListener;
/*     */ 
/*     */   public SimpleShakeDetector(Context context, OnShakeListener listener, int updateInterval)
/*     */   {
/*  86 */     this.context = context;
/*  87 */     this.mListener = listener;
/*     */ 
/*  89 */     this.mSensors = new KyneticsSensors();
/*  90 */     setUpdateInterval(updateInterval);
/*     */ 
/*  92 */     init();
/*     */   }
/*     */ 
/*     */   private void init()
/*     */   {
/*  97 */     this.mSensors.init(this.mUpdateInterval);
/*     */ 
/*  99 */     this.update = new Runnable()
/*     */     {
/*     */       public void run() {
/* 102 */         KyneticsSensors me = SimpleShakeDetector.this.mSensors;
/*     */ 
/* 104 */         Vector3 v = me.getAccel();
/* 105 */         SimpleShakeDetector.this.onNewSensorValue((float)v.X, (float)v.Y, (float)v.Z);
/* 106 */         if (!SimpleShakeDetector.this.stopped)
/* 107 */           SimpleShakeDetector.this.handler.postDelayed(SimpleShakeDetector.this.update, SimpleShakeDetector.this.mUpdateInterval);
/*     */       }
/*     */     };
/* 111 */     this.handler.postDelayed(this.update, this.mUpdateInterval);
/*     */   }
/*     */ 
/*     */   private float calcVectorNorm(float[] values)
/*     */   {
/* 117 */     float norm = Math.abs((float)Math.sqrt(values[0] * values[0] + values[1] * values[1] + values[2] * values[2]) - 9.8F);
/* 118 */     return norm;
/*     */   }
/*     */ 
/*     */   private void onNewSensorValue(float x, float y, float z) {
/* 122 */     float[] v = new float[3];
/* 123 */     v[0] = x;
/* 124 */     v[1] = y;
/* 125 */     v[2] = z;
/*     */ 
/* 127 */     if (calcVectorNorm(v) >= this.mThreshold) {
/* 128 */       this.steps += 1;
/* 129 */       this.stepsNoMov = 0;
/*     */     } else {
/* 131 */       this.stepsNoMov += 1;
/*     */     }
/*     */ 
/* 134 */     if (this.stepsNoMov >= this.mNoMovement) {
/* 135 */       if (this.steps >= this.mMinGestureSize)
/* 136 */         onShakeDetected(this.steps);
/* 137 */       this.steps = 0;
/* 138 */       this.stepsNoMov = 0;
/*     */     }
/*     */   }
/*     */ 
/*     */   private void onShakeDetected(int n)
/*     */   {
/* 144 */     if (this.mListener != null) {
/* 145 */       this.mListener.onShakeDetected(n);
/*     */     }
/* 147 */     Log.d("SimpleShakeDetector", "Shake detected");
/*     */   }
/*     */ 
/*     */   public OnShakeListener getListener()
/*     */   {
/* 157 */     return this.mListener;
/*     */   }
/*     */ 
/*     */   public void setListener(OnShakeListener listener)
/*     */   {
/* 165 */     this.mListener = listener;
/*     */   }
/*     */ 
/*     */   public void onResume()
/*     */   {
/* 174 */     this.stopped = false;
/* 175 */     this.mSensors.onResume();
/* 176 */     this.handler.postDelayed(this.update, this.mUpdateInterval);
/*     */   }
/*     */ 
/*     */   public void onPause()
/*     */   {
/* 185 */     this.stopped = true;
/* 186 */     this.handler.removeCallbacks(this.update);
/* 187 */     this.mSensors.onPause();
/*     */   }
/*     */ 
/*     */   public float getThreshold()
/*     */   {
/* 196 */     return this.mThreshold;
/*     */   }
/*     */ 
/*     */   public void setThreshold(float threshold)
/*     */   {
/* 204 */     this.mThreshold = threshold;
/*     */   }
/*     */ 
/*     */   public int getNoMovement()
/*     */   {
/* 212 */     return this.mNoMovement;
/*     */   }
/*     */ 
/*     */   public void setNoMovement(int noMovement)
/*     */   {
/* 219 */     this.mNoMovement = noMovement;
/*     */   }
/*     */ 
/*     */   public int getUpdateInterval()
/*     */   {
/* 227 */     return this.mUpdateInterval;
/*     */   }
/*     */ 
/*     */   public void setUpdateInterval(int updateInterval)
/*     */   {
/* 235 */     this.mUpdateInterval = updateInterval;
/*     */   }
/*     */ 
/*     */   public int getMinGestureSize()
/*     */   {
/* 243 */     return this.mMinGestureSize;
/*     */   }
/*     */ 
/*     */   public void setMinGestureSize(int minGestureSize)
/*     */   {
/* 250 */     this.mMinGestureSize = minGestureSize;
/*     */   }
/*     */ 
/*     */   public static abstract interface OnShakeListener
/*     */   {
/*     */     public abstract void onShakeDetected(int paramInt);
/*     */   }
/*     */ }

/* Location:
 * Qualified Name:     it.imwatch.SimpleShakeDetector
 * JD-Core Version:    0.6.2
 */